==> tamejs-0.1.5.tgz: package/test/cases/8.out.js <==
var tame = require('tamejs').runtime;
var __tame_fn_0 = function (__tame_k) {
    var assert = require ( "assert" ) ;
    
    var listA = [ ] ;
    var listB = [ ] ;
    
    
    exports [ "for..in iteration" ] = {
    
    run :
    function  (cb) {
        var __tame_this = this;
        var __tame_fn_20 = function (__tame_k) {
            var i = 0 ;
            var __tame_fn_1 = function (__tame_k) {
                var __tame_fn_2 = function (__tame_k) {
                    var __tame_k_implicit =  {};
                    i = 0;
                    var __tame_fn_3 = function (__tame_k) {
                        var __tame_fn_4 = function (__tame_k) {
                            i ++
                            tame.callChain([__tame_fn_3, __tame_k]);
                        };
                        __tame_k_implicit.k_break = __tame_k;
                        __tame_k_implicit.k_continue = function() { __tame_fn_4(__tame_k); };
                        if (i < 10) {
                            var __tame_fn_5 = function (__tame_k) {
                                var __tame_fn_6 = function (__tame_k) {
                                    var __tame_ev = new tame.Event (__tame_k);
                                    var __tame_fn_7 = function (__tame_k) {
                                        setTimeout ( __tame_ev.mkevent ( ) , 10* Math .random ( ) ) ;
                                        tame.callChain([__tame_k]);
                                    };
                                    __tame_fn_7(tame.end);
                                    __tame_ev.trigger();
                                };
                                var __tame_fn_8 = function (__tame_k) {
                                    listA .push ( i ) ;
                                    tame.callChain([__tame_k]);
                                };
                                tame.callChain([__tame_fn_6, __tame_fn_8, __tame_k]);
                            };
                            tame.callChain([__tame_fn_5, __tame_fn_4, __tame_k]);
                        } else {
                            tame.callChain([__tame_k]);
                        }
                    };
                    tame.callChain([__tame_fn_3, __tame_k]);
                };
                var __tame_fn_9 = function (__tame_k) {
                     for (; i < 20 ; i ++) {
                        listA .push ( i ) ;
                    }
                    tame.callChain([__tame_k]);
                };
                var __tame_fn_10 = function (__tame_k) {
                    var __tame_k_implicit =  {};
                    var __tame_fn_11 = function (__tame_k) {
                        if (true) {
                            var __tame_fn_12 = function (__tame_k) {
                                var __tame_fn_13 = function (__tame_k) {
                                    var __tame_fn_14 = function (__tame_k) {
                                        __tame_k_implicit.k_break();
                                    };
                                    if (i >= 30) {
                                        tame.callChain([__tame_fn_14, __tame_k]);
                                    } else {
                                        tame.callChain([__tame_k]);
                                    }
                                };
                                var __tame_fn_15 = function (__tame_k) {
                                    var __tame_ev = new tame.Event (__tame_k);
                                    var __tame_fn_16 = function (__tame_k) {
                                        setTimeout ( __tame_ev.mkevent ( ) , 10* Math .random ( ) ) ;
                                        tame.callChain([__tame_k]);
                                    };
                                    __tame_fn_16(tame.end);
                                    __tame_ev.trigger();
                                };
                                var __tame_fn_17 = function (__tame_k) {
                                    listA .push ( i ) ;
                                    i ++ ;
                                    tame.callChain([__tame_k]);
                                };
                                tame.callChain([__tame_fn_13, __tame_fn_15, __tame_fn_17, __tame_k]);
                            };
                            tame.callChain([__tame_fn_12, __tame_fn_11, __tame_k]);
                        } else {
                            tame.callChain([__tame_k]);
                        }
                    };
                    __tame_k_implicit.k_break = __tame_k;
                    __tame_k_implicit.k_continue = function() { __tame_fn_11(__tame_k); };
                    tame.callChain([__tame_fn_11, __tame_k]);
                };
                var __tame_fn_18 = function (__tame_k) {
                    while (true) {
                        if (i >= 40) {
                            break ;
                        } else {
                        }
                        listA .push ( i ) ;
                        i ++ ;
                    }
                    tame.callChain([__tame_k]);
                };
                var __tame_fn_19 = function (__tame_k) {
                    cb ( ) ;
                    tame.callChain([__tame_k]);
                };
                tame.callChain([__tame_fn_2, __tame_fn_9, __tame_fn_10, __tame_fn_18, __tame_fn_19, __tame_k]);
            };
            tame.callChain([__tame_fn_1, __tame_k]);
        };
        tame.callChain([__tame_fn_20, __tame_k]);
    }
    ,
    
    check :
    function  () {
         for (var i = 0 ; i < 40 ; i ++) {
            listB .push ( i ) ;
        }
        assert .deepEqual ( listA , listB , "list equivalence" ) ;
    }
    } ;
    tame.callChain([__tame_k]);
};
__tame_fn_0 (tame.end);

==> tamejs-0.2.1.tgz: package/test/cases/8.out.js <==
var tame = require('tamejs').runtime;
var __tame_fn_0 = function (__tame_k) {
    var assert = require ( "assert" ) ;
    
    var listA = [ ] ;
    var listB = [ ] ;
    
    
    exports [ "for..in iteration" ] = {
    
    run :
    function  (cb) {
        var __tame_this = this;
        var __tame_fn_20 = function (__tame_k) {
            var i = 0 ;
            var __tame_fn_1 = function (__tame_k) {
                var __tame_fn_2 = function (__tame_k) {
                    var __tame_k_implicit =  {};
                    i = 0;
                    var __tame_fn_3 = function (__tame_k) {
                        var __tame_fn_4 = function (__tame_k) {
                            i ++
                            tame.callChain([__tame_fn_3, __tame_k]);
                        };
                        __tame_k_implicit.k_break = __tame_k;
                        __tame_k_implicit.k_continue = function() { __tame_fn_4(__tame_k); };
                        if (i < 10) {
                            var __tame_fn_5 = function (__tame_k) {
                                var __tame_fn_6 = function (__tame_k) {
                                    var __tame_ev = new tame.Event (__tame_k);
                                    var __tame_fn_7 = function (__tame_k) {
                                        setTimeout (
                                        __tame_ev.mkevent ()
                                        , 10* Math .random ( ) ) ;
                                        tame.callChain([__tame_k]);
                                    };
                                    __tame_fn_7(tame.end);
                                    __tame_ev.trigger();
                                };
                                var __tame_fn_8 = function (__tame_k) {
                                    listA .push ( i ) ;
                                    tame.callChain([__tame_k]);
                                };
                                tame.callChain([__tame_fn_6, __tame_fn_8, __tame_k]);
                            };
                            tame.callChain([__tame_fn_5, __tame_fn_4, __tame_k]);
                        } else {
                            tame.callChain([__tame_k]);
                        }
                    };
                    tame.callChain([__tame_fn_3, __tame_k]);
                };
                var __tame_fn_9 = function (__tame_k) {
                     for (; i < 20 ; i ++) {
                        listA .push ( i ) ;
                    }
                    tame.callChain([__tame_k]);
                };
                var __tame_fn_10 = function (__tame_k) {
                    var __tame_k_implicit =  {};
                    var __tame_fn_11 = function (__tame_k) {
                        if (true) {
                            var __tame_fn_12 = function (__tame_k) {
                                var __tame_fn_13 = function (__tame_k) {
                                    var __tame_fn_14 = function (__tame_k) {
                                        __tame_k_implicit.k_break();
                                    };
                                    if (i >= 30) {
                                        tame.callChain([__tame_fn_14, __tame_k]);
                                    } else {
                                        tame.callChain([__tame_k]);
                                    }
                                };
                                var __tame_fn_15 = function (__tame_k) {
                                    var __tame_ev = new tame.Event (__tame_k);
                                    var __tame_fn_16 = function (__tame_k) {
                                        setTimeout (
                                        __tame_ev.mkevent ()
                                        , 10* Math .random ( ) ) ;
                                        tame.callChain([__tame_k]);
                                    };
                                    __tame_fn_16(tame.end);
                                    __tame_ev.trigger();
                                };
                                var __tame_fn_17 = function (__tame_k) {
                                    listA .push ( i ) ;
                                    i ++ ;
                                    tame.callChain([__tame_k]);
                                };
                                tame.callChain([__tame_fn_13, __tame_fn_15, __tame_fn_17, __tame_k]);
                            };
                            tame.callChain([__tame_fn_12, __tame_fn_11, __tame_k]);
                        } else {
                            tame.callChain([__tame_k]);
                        }
                    };
                    __tame_k_implicit.k_break = __tame_k;
                    __tame_k_implicit.k_continue = function() { __tame_fn_11(__tame_k); };
                    tame.callChain([__tame_fn_11, __tame_k]);
                };
                var __tame_fn_18 = function (__tame_k) {
                    while (true) {
                        if (i >= 40) {
                            break ;
                        } else {
                        }
                        listA .push ( i ) ;
                        i ++ ;
                    }
                    tame.callChain([__tame_k]);
                };
                var __tame_fn_19 = function (__tame_k) {
                    cb ( ) ;
                    tame.callChain([__tame_k]);
                };
                tame.callChain([__tame_fn_2, __tame_fn_9, __tame_fn_10, __tame_fn_18, __tame_fn_19, __tame_k]);
            };
            tame.callChain([__tame_fn_1, __tame_k]);
        };
        tame.callChain([__tame_fn_20, __tame_k]);
    }
    ,
    
    check :
    function  () {
         for (var i = 0 ; i < 40 ; i ++) {
            listB .push ( i ) ;
        }
        assert .deepEqual ( listA , listB , "list equivalence" ) ;
    }
    } ;
    tame.callChain([__tame_k]);
};
__tame_fn_0 (tame.end);
